pulsar.managers.util.cli.shell package
======================================

Submodules
----------

pulsar.managers.util.cli.shell.local module
-------------------------------------------

.. automodule:: pulsar.managers.util.cli.shell.local
    :members:
    :undoc-members:
    :show-inheritance:

pulsar.managers.util.cli.shell.rsh module
-----------------------------------------

.. automodule:: pulsar.managers.util.cli.shell.rsh
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pulsar.managers.util.cli.shell
    :members:
    :undoc-members:
    :show-inheritance:
